summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorTom Proctor <tomhjp@users.noreply.github.com>2024-12-03 15:02:42 +0000
committerGitHub <noreply@github.com>2024-12-03 15:02:42 +0000
commitefdfd547979fc09ea30d96bf31fcc06cadc538f3 (patch)
tree1cb05692cee8c1fd24f05ae70731e71a7609c402
parent9f9063e624c66d295d286d2f7bc85c02dfd46d4f (diff)
downloadtailscale-efdfd547979fc09ea30d96bf31fcc06cadc538f3.tar.xz
tailscale-efdfd547979fc09ea30d96bf31fcc06cadc538f3.zip
cmd/k8s-operator: avoid port collision with metrics endpoint (#14185)
When the operator enables metrics on a proxy, it uses the port 9001, and in the near future it will start using 9002 for the debug endpoint as well. Make sure we don't choose ports from a range that includes 9001 so that we never clash. Setting TS_SOCKS5_SERVER, TS_HEALTHCHECK_ADDR_PORT, TS_OUTBOUND_HTTP_PROXY_LISTEN, and PORT could also open arbitrary ports, so we will need to document that users should not choose ports from the 10000-11000 range for those settings. Updates #13406 Signed-off-by: Tom Proctor <tomhjp@users.noreply.github.com>
-rw-r--r--cmd/k8s-operator/egress-services.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/cmd/k8s-operator/egress-services.go b/cmd/k8s-operator/egress-services.go
index a562f0170..17746b470 100644
--- a/cmd/k8s-operator/egress-services.go
+++ b/cmd/k8s-operator/egress-services.go
@@ -51,12 +51,12 @@ const (
labelSvcType = "tailscale.com/svc-type" // ingress or egress
typeEgress = "egress"
// maxPorts is the maximum number of ports that can be exposed on a
- // container. In practice this will be ports in range [3000 - 4000). The
+ // container. In practice this will be ports in range [10000 - 11000). The
// high range should make it easier to distinguish container ports from
// the tailnet target ports for debugging purposes (i.e when reading
// netfilter rules). The limit of 10000 is somewhat arbitrary, the
// assumption is that this would not be hit in practice.
- maxPorts = 10000
+ maxPorts = 1000
indexEgressProxyGroup = ".metadata.annotations.egress-proxy-group"
)
@@ -254,7 +254,7 @@ func (esr *egressSvcsReconciler) provision(ctx context.Context, proxyGroupName s
if !found {
// Calculate a free port to expose on container and add
// a new PortMap to the ClusterIP Service.
- if usedPorts.Len() == maxPorts {
+ if usedPorts.Len() >= maxPorts {
// TODO(irbekrm): refactor to avoid extra reconciles here. Low priority as in practice,
// the limit should not be hit.
return nil, false, fmt.Errorf("unable to allocate additional ports on ProxyGroup %s, %d ports already used. Create another ProxyGroup or open an issue if you believe this is unexpected.", proxyGroupName, maxPorts)
@@ -548,13 +548,13 @@ func svcNameBase(s string) string {
}
}
-// unusedPort returns a port in range [3000 - 4000). The caller must ensure that
-// usedPorts does not contain all ports in range [3000 - 4000).
+// unusedPort returns a port in range [10000 - 11000). The caller must ensure that
+// usedPorts does not contain all ports in range [10000 - 11000).
func unusedPort(usedPorts sets.Set[int32]) int32 {
foundFreePort := false
var suggestPort int32
for !foundFreePort {
- suggestPort = rand.Int32N(maxPorts) + 3000
+ suggestPort = rand.Int32N(maxPorts) + 10000
if !usedPorts.Has(suggestPort) {
foundFreePort = true
}
@@ -51,12 +51,12 @@ const (
// high range should make it easier to distinguish container ports from
// the tailnet target ports for debugging purposes (i.e when reading
- // netfilter rules). The limit of 10000 is somewhat arbitrary, the
+ // netfilter rules). The limit of 1000 is somewhat arbitrary, the
// assumption is that this would not be hit in practice.